package com.muyu.quest.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.muyu.quest.domain.Node;
import jakarta.servlet.http.HttpServletResponse;
import javax.annotation.Resource;

import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.quest.domain.NodeDisposition;
import com.muyu.quest.service.INodeDispositionService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.security.utils.SecurityUtils;
import org.springframework.validation.annotation.Validated;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 节点配置Controller
 *
 * @author 2112A
 * @date 2024-08-29
 */
@RestController
@RequestMapping("/disposition")
public class NodeDispositionController extends BaseController
{
    @Resource
    private INodeDispositionService nodeDispositionService;

    /**
     * 查询节点配置列表
     */
    @RequiresPermissions("quest:disposition:list")
    @GetMapping("/list")
    public Result<TableDataInfo<NodeDisposition>> list(NodeDisposition nodeDisposition)
    {
        startPage();
        List<NodeDisposition> list = nodeDispositionService.selectNodeDispositionList(nodeDisposition);
        return getDataTable(list);
    }

    /**
     * 导出节点配置列表
     */
    @RequiresPermissions("quest:disposition:export")
    @PostMapping("/export")
    public void export(HttpServletResponse response, NodeDisposition nodeDisposition)
    {
        List<NodeDisposition> list = nodeDispositionService.selectNodeDispositionList(nodeDisposition);
        ExcelUtil<NodeDisposition> util = new ExcelUtil<NodeDisposition>(NodeDisposition.class);
        util.exportExcel(response, list, "节点配置数据");
    }

    /**
     * 获取节点配置详细信息
     */
    @RequiresPermissions("quest:disposition:query")
    @GetMapping(value = "/{id}")
    public Result<List<NodeDisposition>> getInfo(@PathVariable("id") Long id)
    {
        return success(nodeDispositionService.selectNodeDispositionById(id));
    }

    /**
     * 新增节点配置
     */
    @RequiresPermissions("quest:disposition:add")
    @PostMapping
    public Result<Integer> add(
            @Validated @RequestBody NodeDisposition nodeDisposition)
    {
        if (nodeDispositionService.checkIdUnique(nodeDisposition)) {
            return error("新增 节点配置 '" + nodeDisposition + "'失败，节点配置已存在");
        }
        return toAjax(nodeDispositionService.save(nodeDisposition));
    }

    /**
     * 修改节点配置
     */
    @RequiresPermissions("quest:disposition:edit")
    @PutMapping
    public Result<Integer> edit(
            @Validated @RequestBody NodeDisposition nodeDisposition)
    {
        if (!nodeDispositionService.checkIdUnique(nodeDisposition)) {
            nodeDispositionService.save(nodeDisposition);
        }
        return toAjax(nodeDispositionService.updateById(nodeDisposition));
    }

    /**
     * 删除节点配置
     */
    @RequiresPermissions("quest:disposition:remove")
	@DeleteMapping("/{ids}")
    public Result<Integer> remove(@PathVariable("ids") Long[] ids)
    {
        nodeDispositionService.removeBatchByIds(Arrays.asList(ids));
        return success();
    }

    /**
     * 批量删除与新增
     */
    @PostMapping("/batch/{nodeCode}")
    @Transactional
    public Result<Integer> batch(
            @Validated @RequestBody ArrayList<NodeDisposition> dispList,
            @PathVariable("nodeCode") String nodeCode){
        // 根据节点编码删除
        nodeDispositionService.batchDelect(nodeCode);
        // 批量新增
        if (!dispList.isEmpty()) {
            nodeDispositionService.saveBatch(dispList);
        }
        return success();
    }
}
