package com.muyu.quest.service.impl;

import java.util.List;
import org.springframework.stereotype.Service;
import com.muyu.quest.mapper.NodeDispositionMapper;
import com.muyu.quest.domain.NodeDisposition;
import com.muyu.quest.service.INodeDispositionService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import org.springframework.util.Assert;

/**
 * 节点配置Service业务层处理
 *
 * @author 2112A
 * @date 2024-08-29
 */
@Service
public class NodeDispositionServiceImpl
        extends ServiceImpl<NodeDispositionMapper, NodeDisposition>
        implements INodeDispositionService {

    /**
     * 精确查询节点配置
     *
     * @param id 节点配置主键
     * @return 节点配置
     */
    @Override
    public NodeDisposition selectNodeDispositionById(Long id)
    {
        LambdaQueryWrapper<NodeDisposition> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(id, "id不可为空");
        queryWrapper.eq(NodeDisposition::getId, id);
        return this.getOne(queryWrapper);
    }


    /**
     * 查询节点配置列表
     *
     * @param nodeDisposition 节点配置
     * @return 节点配置
     */
    @Override
    public List<NodeDisposition> selectNodeDispositionList(NodeDisposition nodeDisposition)
    {
        LambdaQueryWrapper<NodeDisposition> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(nodeDisposition.getNodeCode())){
            queryWrapper.eq(NodeDisposition::getNodeCode, nodeDisposition.getNodeCode());
        }
        if (StringUtils.isNotEmpty(nodeDisposition.getDispKey())){
            queryWrapper.eq(NodeDisposition::getDispKey, nodeDisposition.getDispKey());
        }
        if (StringUtils.isNotEmpty(nodeDisposition.getDispLabel())){
            queryWrapper.eq(NodeDisposition::getDispLabel, nodeDisposition.getDispLabel());
        }
        if (StringUtils.isNotEmpty(nodeDisposition.getDispType())){
            queryWrapper.eq(NodeDisposition::getDispType, nodeDisposition.getDispType());
        }
        return this.list(queryWrapper);
    }

    /**
    * 唯一 判断
    * @param nodeDisposition 节点配置
     * @return 节点配置
    */
    @Override
    public Boolean checkIdUnique(NodeDisposition nodeDisposition) {
        LambdaQueryWrapper<NodeDisposition> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(NodeDisposition::getId, nodeDisposition.getId());
        return this.count(queryWrapper) > 0;
    }

    @Override
    public Boolean checkDispUnique(NodeDisposition disp) {
        LambdaQueryWrapper<NodeDisposition> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(NodeDisposition::getId, disp.getId());
        queryWrapper.eq(NodeDisposition::getNodeCode, disp.getNodeCode());
        return this.exists(queryWrapper);
    }

    @Override
    public void batchDelect(String nodeCode) {
        LambdaQueryWrapper<NodeDisposition> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(NodeDisposition::getNodeCode, nodeCode);
        this.remove(queryWrapper);
    }

}
