package com.muyu.quest.service.impl;

import java.util.Arrays;
import java.util.List;

import com.muyu.quest.req.NodeReq;
import com.muyu.quest.service.INodeDispositionService;
import org.springframework.stereotype.Service;
import com.muyu.quest.mapper.NodeMapper;
import com.muyu.quest.domain.Node;
import com.muyu.quest.service.INodeService;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import org.springframework.util.Assert;

import javax.annotation.Resource;

/**
 * 节点管理Service业务层处理
 *
 * @author 2112A
 * @date 2024-08-23
 */
@Service
public class NodeServiceImpl
        extends ServiceImpl<NodeMapper, Node>
        implements INodeService {

    /**
     * 精确查询节点管理
     *
     * @param id 节点管理主键
     * @return 节点管理
     */
    @Override
    public Node selectNodeById(Long id)
    {
        LambdaQueryWrapper<Node> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(id, "id不可为空");
        queryWrapper.eq(Node::getId, id);
        return this.getOne(queryWrapper);
    }


    /**
     * 查询节点管理列表
     *
     * @param nodeReq 节点管理
     * @return 节点管理
     */
    @Override
    public List<Node> selectNodeList(NodeReq nodeReq)
    {
        LambdaQueryWrapper<Node> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(nodeReq.getTaskCode())){
            queryWrapper.eq(Node::getTaskCode, nodeReq.getTaskCode());
        }
        if (StringUtils.isNotEmpty(nodeReq.getNodeName())){
            queryWrapper.like(Node::getNodeName, nodeReq.getNodeName());
        }
        if (StringUtils.isNotEmpty(nodeReq.getNodePreCode())){
            queryWrapper.eq(Node::getNodePreCode, nodeReq.getNodePreCode());
        }
        if (StringUtils.isNotEmpty(nodeReq.getNodeNextCode())){
            queryWrapper.eq(Node::getNodeNextCode, nodeReq.getNodeNextCode());
        }
        if (StringUtils.isNotEmpty(nodeReq.getState())){
            queryWrapper.eq(Node::getState, nodeReq.getState());
        }
        return this.list(queryWrapper);
    }

    /**
    * 唯一 判断
    * @param node 节点管理
     * @return 节点管理
    */
    @Override
    public Boolean checkIdUnique(Node node) {
        LambdaQueryWrapper<Node> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(Node::getId, node.getId());
        return this.exists(queryWrapper);
    }

    @Override
    public List<Node> selectNodeByIds(Long[] ids) {
        LambdaQueryWrapper<Node> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(Node::getId, Arrays.asList(ids));
        return this.list(queryWrapper);
    }

    @Override
    public void batchDelect(String taskCode) {
        LambdaQueryWrapper<Node> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(Node::getTaskCode,taskCode);
        this.remove(queryWrapper);
    }


}
