package com.muyu.quest.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.quest.req.TaskReq;
import com.muyu.quest.resp.TaskResp;
import com.muyu.quest.service.INodeService;
import org.springframework.stereotype.Service;
import com.muyu.quest.mapper.TaskMapper;
import com.muyu.quest.domain.Task;
import com.muyu.quest.service.TaskService;
import org.springframework.util.Assert;

import javax.annotation.Resource;

/**
 * 任务Service业务层处理
 *
 * @author 2112A
 * @date 2024-08-22
 */
@Service
public class TaskServiceImpl extends ServiceImpl<TaskMapper, Task>
        implements TaskService {

    /**
     * 查询任务
     *
     * @param taskCode 任务编码
     * @return 任务
     */
    @Override
    public Task selectTaskByTaskCode(String taskCode)
    {
        LambdaQueryWrapper<Task> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(taskCode, "taskCode不可为空");
        queryWrapper.eq(Task::getTaskCode, taskCode);
        return this.getOne(queryWrapper);
    }

    /**
     * 查询任务
     *
     * @param id 任务主键
     * @return 任务
     */
    @Override
    public Task selectTaskById(Long id)
    {
        LambdaQueryWrapper<Task> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(id, "id不可为空");
        queryWrapper.eq(Task::getId, id);
        return this.getOne(queryWrapper);
    }

    /**
     * 唯一编码判断
     * @param task
     * @return
     */
    @Override
    public Boolean checkTaskCodeUnique(Task task) {
        LambdaQueryWrapper<Task> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(Task::getTaskCode, task.getTaskCode());
        return this.exists(queryWrapper);
    }

    @Override
    public Boolean checkIdUnique(Task task) {
        LambdaQueryWrapper<Task> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(Task::getId, task.getId());
        return this.exists(queryWrapper);
    }

    @Override
    public void removeBatch(List<Long> list) {
        this.removeBatchByIds(list);
    }

    @Override
    public String execute(String taskCode) {
        return "";
    }

    /**
     * 查询任务列表
     *
     * @param taskReq 任务
     * @return 任务
     */
    @Override
    public List<TaskResp> selectTaskList(TaskReq taskReq)
    {
        LambdaQueryWrapper<Task> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(taskReq.getTaskName())){
            queryWrapper.like(Task::getTaskName, taskReq.getTaskName());
        }
        if (StringUtils.isNotEmpty(taskReq.getState())){
            queryWrapper.eq(Task::getState, taskReq.getState());
        }
        if (StringUtils.isNotEmpty(taskReq.getTaskType())){
            queryWrapper.eq(Task::getTaskType, taskReq.getTaskType());
        }
        return this.list(queryWrapper)
                .stream()
                .map(TaskResp::build)
                .toList();
    }


}
